"use strict";
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const parser_1 = require("@babel/parser");
const core_1 = require("@babel/core");
const generator_1 = tslib_1.__importDefault(require("@babel/generator"));
const flipperRequires = require('../flipper-requires');
const babelOptions = {
    ast: true,
    plugins: [flipperRequires],
    filename: 'index.js',
};
test('transform react requires to global object', () => {
    const src = 'require("react")';
    const ast = parser_1.parse(src);
    const transformed = core_1.transformFromAstSync(ast, src, babelOptions).ast;
    const { code } = generator_1.default(transformed);
    expect(code).toBe('global.React;');
});
test('transform react-dom requires to global object', () => {
    const src = 'require("react-dom")';
    const ast = parser_1.parse(src);
    const transformed = core_1.transformFromAstSync(ast, src, babelOptions).ast;
    const { code } = generator_1.default(transformed);
    expect(code).toBe('global.ReactDOM;');
});
test('transform flipper requires to global object', () => {
    const src = 'require("flipper")';
    const ast = parser_1.parse(src);
    const transformed = core_1.transformFromAstSync(ast, src, babelOptions).ast;
    const { code } = generator_1.default(transformed);
    expect(code).toBe('global.Flipper;');
});
test('transform React identifier to global.React', () => {
    const src = 'React;';
    const ast = parser_1.parse(src);
    const transformed = core_1.transformFromAstSync(ast, src, babelOptions).ast;
    const { code } = generator_1.default(transformed);
    expect(code).toBe('global.React;');
});
test.skip('throw error when requiring outside the plugin', () => {
    const src = 'require("../test.js")';
    const ast = parser_1.parse(src);
    expect(() => {
        core_1.transformFromAstSync(ast, src, babelOptions);
    }).toThrow();
});
test('allow requiring from parent folder as long as we stay in plugin folder', () => {
    const src = 'require("../test.js")';
    const ast = parser_1.parse(src);
    const transformed = core_1.transformFromAstSync(ast, src, Object.assign(Object.assign({}, babelOptions), { root: '/path/to/plugin', filename: '/path/to/plugin/subfolder/index.js' })).ast;
    const { code } = generator_1.default(transformed);
    expect(code).toBe('require("../test.js");');
});
//# sourceMappingURL=flipper-requires.node.js.map